@@ -15,3 +15,6 @@ from .t_python_markdown import CodeBlock
 from .t_python_markdown import UnorderedList
 from .t_python_markdown import OrderedList
 from .t_python_markdown import Table
+
+from .t_python_markdown import NotAllowedException
+from .t_python_markdown import BadFormatException
\ No newline at end of file
